==> haskell-time-compat-1.9.6.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-compat
version:              1.9.6.1
visibility:           public
id:                   time-compat-1.9.6.1-74DLQSiinrV5Zepvuhk4nM
key:                  time-compat-1.9.6.1-74DLQSiinrV5Zepvuhk4nM
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  215f912cc41a60ac19e46a5e0e97bfa7
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.Private Data.Time.Calendar.Types
    Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.0.1/site-local/time-compat-1.9.6.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/time-compat-1.9.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/time-compat-1.9.6.1
hs-libraries:         HStime-compat-1.9.6.1-74DLQSiinrV5Zepvuhk4nM
depends:
    base-4.15.0.0 base-orphans-0.8.4-7HXGrYvuRnN62MKHDhd51W
    deepseq-1.4.5.0 hashable-1.3.3.0-LgC2GKp34OLEabneGtyuCb time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-compat-1.9.6.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-compat
version:              1.9.6.1
visibility:           public
id:                   time-compat-1.9.6.1-FG1vxonblFBCprcW40t5n7
key:                  time-compat-1.9.6.1-FG1vxonblFBCprcW40t5n7
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  ffe1dc9c8d426ce34959e8534de53c30
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.Private Data.Time.Calendar.Types
    Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.0.1/site-local/time-compat-1.9.6.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/time-compat-1.9.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/time-compat-1.9.6.1
hs-libraries:         HStime-compat-1.9.6.1-FG1vxonblFBCprcW40t5n7
depends:
    base-4.15.0.0 base-orphans-0.8.5-LtEBU9Ms0DHOGKjXhH1L9
    deepseq-1.4.5.0 hashable-1.3.3.0-23uoxU4x6MLFe9vf4ULvQk time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
